MethodChannelNfcWalletSuppression class

An implementation of NfcWalletSuppressionPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSuppressed() Future<bool>
Checks if the NFC wallet is currently suppressed.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseSuppression() Future<SuppressionStatus>
Releases the suppression of the NFC wallet.
override
requestSuppression() Future<SuppressionStatus>
Requests suppression of the NFC wallet.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited