NfcWalletSuppression class

Provides a mechanism to suppress the system's NFC wallet behavior.

This class allows you to temporarily prevent the system from showing its NFC wallet UI when an NFC tag is detected.

Constructors

NfcWalletSuppression()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isSuppressed() Future<bool>
Checks if the system's NFC wallet behavior is currently suppressed.
releaseSuppression() Future<SuppressionStatus>
Releases suppression of the system's NFC wallet behavior.
requestSuppression() Future<SuppressionStatus>
Requests suppression of the system's NFC wallet behavior.