NfcWalletSuppressionPlatform class abstract

An interface for a platform-specific implementation of the nfc_wallet_suppression plugin.

This class provides methods to request and release suppression of the NFC wallet. The platform-specific implementation should provide their own class that extends this one to be able to call the platform specific API.

Inheritance
  • Object
  • PlatformInterface
  • NfcWalletSuppressionPlatform
Implementers

Constructors

NfcWalletSuppressionPlatform()
Constructs a NfcWalletSuppressionPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSuppressed() Future<bool>
Check if the NFC wallet is currently suppressed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseSuppression() Future<SuppressionStatus>
Release suppression of the NFC wallet.
requestSuppression() Future<SuppressionStatus>
Request suppression of the NFC wallet.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NfcWalletSuppressionPlatform
The default instance of NfcWalletSuppressionPlatform to use.
getter/setter pair