SuppressionStatus enum
Enum representing the status of suppression for NFC wallet interaction.
notSuppressed: The NFC wallet interaction is not suppressed.suppressed: The NFC wallet interaction is suppressed.unavailable: The NFC wallet interaction suppression is unavailable.denied: The NFC wallet interaction suppression was denied.cancelled: The NFC wallet interaction suppression was cancelled.notSupported: The NFC wallet interaction suppression is not supported.alreadyPresenting: The NFC wallet interaction is already presenting.unknown: The NFC wallet interaction suppression status is unknown.
This enum provides a structured way to represent different states related to the suppression of NFC wallet interactions.
Values
- notSuppressed → const SuppressionStatus
-
notSuppressed: The NFC wallet interaction is not suppressed. - suppressed → const SuppressionStatus
-
suppressed: The NFC wallet interaction is suppressed. -
unavailable: The NFC wallet interaction suppression is unavailable. - denied → const SuppressionStatus
-
denied: The NFC wallet interaction suppression was denied. - cancelled → const SuppressionStatus
-
cancelled: The NFC wallet interaction suppression was cancelled. - notSupported → const SuppressionStatus
-
notSupported: The NFC wallet interaction suppression is not supported. - alreadyPresenting → const SuppressionStatus
-
alreadyPresenting: The NFC wallet interaction is already presenting. - unknown → const SuppressionStatus
-
unknown: The NFC wallet interaction suppression status is unknown.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SuppressionStatus> - A constant List of the values in this enum, in order of their declaration.