FakeNfcWalletSuppression class
A fake implementation of NfcWalletSuppressionPlatform for testing.
This allows you to control the behavior of the plugin in tests without needing real NFC hardware or platform-specific code.
Use setSupported, setRequestResult, etc. to configure behavior.
- Inheritance
-
- Object
- PlatformInterface
- NfcWalletSuppressionPlatform
- FakeNfcWalletSuppression
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methodCalls
→ List<
String> -
Track method calls for verification in tests
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isSupported(
) → Future< bool> -
Check if the device supports NFC wallet suppression.
override
-
isSuppressed(
) → Future< bool> -
Check if the NFC wallet is currently suppressed.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
releaseSuppression(
) → Future< SuppressionStatus> -
Release suppression of the NFC wallet.
override
-
requestSuppression(
) → Future< SuppressionStatus> -
Request suppression of the NFC wallet.
override
-
reset(
) → void - Reset all state and call history
-
setReleaseResult(
SuppressionStatus result) → void - Set the result that releaseSuppression will return
-
setRequestResult(
SuppressionStatus result) → void - Set the result that requestSuppression will return
-
setSupported(
bool supported) → void - Set whether the device supports NFC wallet suppression
-
setSuppressed(
bool suppressed) → void - Manually set the suppressed state (simulates an external state change).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited