NfcWalletSuppressionTestScenarios class
Test helper to create common test scenarios
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
alreadyPresenting(
) → FakeNfcWalletSuppression - Scenario: Already presenting passes (iOS)
- Scenario: NFC is available but currently unavailable (e.g., disabled)
-
supportedDevice(
) → FakeNfcWalletSuppression - Scenario: Device supports NFC and suppression works normally
-
unsupportedDevice(
) → FakeNfcWalletSuppression - Scenario: Device does not support NFC
-
userCancelled(
) → FakeNfcWalletSuppression - Scenario: User cancelled the suppression prompt (iOS)
-
userDenied(
) → FakeNfcWalletSuppression - Scenario: User denied permission (iOS)